=======
History
=======

0.2.8 (2018-04-10)
------------------

* Add single_row decorator
* Fix naming of match UDF to similar
* Add UDF sha3
* Add UDF nounce
* Add UDF hex
* Satisfy linter

0.2.7 (2018-04-03)
------------------

* Update docs
* Remove old sqlfunc code
* Add UDF cbor, uncbor
* Add helper to list history

0.2.6 (2018-04-03)
------------------

* Add UDF number
* Disable support for Python 3.4 (Travis CI)
* Add dependency typeguard
* Add UDF match

0.2.2 (2018-03-31)
------------------

* Automatic deployment to PyPI.

0.2.1 (2018-03-31)
------------------

* Various fixes to the repo.

0.2.0 (2018-03-31)
------------------

* Moved project to the cookiecutter-pypackage template.
* Disabled support for Python 2.7.
